@@ -10,7 +10,7 @@ package TeX::DVI;
 use FileHandle;
 use Font::TFM;
 
-$VERSION = '0.101';
+$VERSION = '1.01';
 
 sub new
 	{
@@ -249,13 +249,20 @@ know why you call the method you call.
 
 =head1 VERSION
 
-0.101
+1.01
+
+=head1 AVAILABLE FROM
+
+http://www.adelton.com/perl/TeX-DVI/
 
 =head1 AUTHOR
 
-(c) 1996--2001 Jan Pazdziora, adelton@fi.muni.cz,
-http://www.fi.muni.cz/~adelton/ at Faculty of Informatics, Masaryk
-University in Brno, Czech Republic
+(c) 1996--2011 Jan Pazdziora.
+
+All rights reserved. This package is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
+
+Contact the author at jpx dash perl at adelton dot com.
 
 =head1 SEE ALSO
 
